jet_core/jet_core library

Classes

Engine
JetInterface
JetInterface allows any auxiliary package to be merged into the "Jet" class through extensions

Enums

SmartManagement
Defines how JetX manages the lifecycle and disposal of controllers and dependencies.

Properties

Jet → _JetImpl
final

Functions

defaultLogWriterCallback(String value, {bool isError = false}) → void
default logger from JetX

Typedefs

LogWriterCallback = void Function(String text, {bool isError})
VoidCallback from logs
ValueUpdater<T> = T Function()