RouteTree class

Constructors

RouteTree()

Properties

hashCode int
The hash code for this object.
no setterinherited
matcher RouteMatcher
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tree Map<String, JetPage>
final

Methods

addRoute(JetPage route) → void
addRoutes(List<JetPage> routes) → void
handleChild(JetPage route) → void
matchRoute(String path) RouteTreeResult?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRoute(JetPage route) → void
removeRoutes(List<JetPage> routes) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance RouteTree
final