ParseRouteTree class

Constructors

ParseRouteTree({required List<JetPage> routes})

Properties

hashCode int
The hash code for this object.
no setterinherited
routes List<JetPage>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRoute<T>(JetPage<T> route) → void
addRoutes<T>(List<JetPage<T>> getPages) → void
matchRoute(String name, {PageSettings? arguments}) RouteDecoder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRoute<T>(JetPage<T> route) → void
removeRoutes<T>(List<JetPage<T>> getPages) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited