onPageCalled method
This function will be called when this Page is called you can use it to change something about the page or give it new page {@tool snippet}
JetPage onPageCalled(JetPage page) {
final authService = Jet.find<AuthService>();
return page.copyWith(title: 'Welcome ${authService.UserName}');
}
{@end-tool}
Implementation
JetPage? onPageCalled(JetPage? page) => page;