MiniStream<T> class

Constructors

MiniStream()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
no setter
isClosed → bool
no setter
length → int
no setter
listenable ↔ FastList<T>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pair

Methods

add(T event) → void
addError(Object error, [StackTrace? stackTrace]) → void
close() → void
listen(void onData(T event), {Function? onError, void onDone()?, bool cancelOnError = false}) → MiniSubscription<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited