jet_state_manager/jet_state_manager library

Classes

Bind<T>
BindElement<T>
The BindElement is responsible for injecting dependencies into the widget tree so that they can be observed
Binder<T>
Binding
Binding should be extended. When using JetMaterialApp, all JetPages and navigation methods (like Jet.to()) have a binding property that takes an instance of Bindings to manage the dependencies() (via Jet.put()) for the Route you are opening.
Binds
CustomStatus<T>
EmptyStatus<T>
ErrorStatus<T, S>
FullLifeCycleController
A controller that can observe the full app lifecycle.
GetListenable<T>
GetNotifier<T>
GetNotifier has a native status and state implementation, with the Get Lifecycle
GetStatus<T>
JetBuilder<T extends JetxController>
JetResponsiveView<T>
Extend this widget to build responsive view. this widget contains the screen property that have all information about the screen size and type. You have two options to build it. 1- with builder method you return the widget to build. 2- with methods desktop, tablet,phone, watch. the specific method will be built when the screen type matches the method when the screen is ScreenType.Tablet the tablet method will be exuded and so on. Note if you use this method please set the property alwaysUseBuilder to false With settings property you can set the width limit for the screen types.
JetResponsiveWidget<T extends JetLifeCycleMixin>
JetView<T>
JetView is a great way of quickly access your Controller without having to call Jet.find<AwesomeController>() yourself.
JetWidget<S extends JetLifeCycleMixin>
JetWidget is a great way of quickly access your individual Controller without having to call Jet.find<AwesomeController>() yourself. Jet save you controller on cache, so, you can to use Jet.create() safely JetWidget is perfect to multiples instance of a same controller. Each JetWidget will have your own controller, and will be call events as onInit and onClose when the controller get in/get out on memory.
JetX<T extends JetLifeCycleMixin>
JetxController
A base controller class that provides state management functionality.
JetXState<T extends JetLifeCycleMixin>
LoadingStatus<T>
Observer
Obx
The simplest reactive widget in JetX.
ObxElement
ObxStatelessWidget
A StatelessWidget than can listen reactive changes.
ObxValue<T extends RxInterface>
Similar to Obx, but manages a local state. Pass the initial data in constructor. Useful for simple local states, like toggles, visibility, themes, button states, etc. Sample: ObxValue((data) => Switch( value: data.value, onChanged: (flag) => data.value = flag, ), false.obs, ),
ObxWidget
The ObxWidget is the base for all JetX reactive widgets
ResponsiveScreen
ResponsiveScreenSettings
RxController
A base controller class for reactive state management using Rx variables.
StateController<T>
A controller that manages state for asynchronous operations.
SuccessStatus<T>
SuperController<T>
A controller that combines full lifecycle management with state management.
Value<T>
ValueBuilder<T>
Manages a local state like ObxValue, but uses a callback instead of a Rx value.
ValueBuilderState<T>

Enums

ScreenType

Mixins

FullLifeCycleMixin
A mixin that provides full lifecycle callbacks for the controller.
GetSingleTickerProviderStateMixin
Used like SingleTickerProviderMixin but only with Get Controllers. Simplifies AnimationController creation inside JetxController.
GetTickerProviderStateMixin
Used like TickerProviderMixin but only with Get Controllers. Simplifies multiple AnimationController creation inside JetxController.
JetResponsiveMixin
ScrollMixin
A mixin that provides scroll-based data fetching capabilities.
SingleGetTickerProviderMixin
Used like SingleTickerProviderMixin but only with Get Controllers. Simplifies AnimationController creation inside JetxController.
StatelessObserverComponent
a Component that can track changes in a reactive variable
StateMixin<T>

Typedefs

FuturizeCallback<T> = Future<T> Function(VoidCallback fn)
InitBuilder<T> = T Function()
JetControllerBuilder<T extends JetLifeCycleMixin> = Widget Function(T controller)
JetXControllerBuilder<T extends JetLifeCycleMixin> = Widget Function(T controller)
NotifierBuilder<T> = Widget Function(T state)
ValueBuilderBuilder<T> = Widget Function(T snapshot, ValueBuilderUpdateCallback<T> updater)
ValueBuilderUpdateCallback<T> = void Function(T snapshot)
VoidCallback = void Function()
WidgetCallback = Widget Function()

Exceptions / Errors

BindError<T>