GetStatus<T> class abstract

Mixed-in types
Implementers
Available extensions

Constructors

GetStatus()
const
GetStatus.custom()
factory
GetStatus.empty()
factory
GetStatus.error(Object message)
factory
GetStatus.loading()
factory
GetStatus.success(T data)
factory

Properties

data → T?

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
error → dynamic

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
errorMessage → String

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
isCustom → bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isEmpty → bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isError → bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isLoading → bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isSuccess → bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
props → List
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited