route_manager library

Jet Navigator allows you to navigate routes, open snackbars, dialogs and bottomsheets easily, and without the need for context.

Enums

PopMode
Enables the user to customize the intended pop behavior
PreventDuplicateHandlingMode
Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
RowStyle
SmartManagement
Defines how JetX manages the lifecycle and disposal of controllers and dependencies.
SnackbarStatus
Indicates Status of snackbar SnackbarStatus.OPEN Snack is fully open, SnackbarStatus.CLOSED Snackbar has closed, SnackbarStatus.OPENING Starts with the opening animation and ends with the full snackbar display, SnackbarStatus.CLOSING Starts with the closing animation and ends with the full snackbar dispose
SnackHoverState
Indicates if the mouse entered or exited
SnackPosition
Indicates if snack is going to start at the TOP or at the BOTTOM
SnackStyle
Indicates if snack will be attached to the edge of the screen or not
Transition

Constants

rtlLanguages → const List<String>

Properties

Jet → _JetImpl
final
It replaces the Flutter Navigator, but needs no context. You can to use navigator.push(YourRoute()) rather Navigator.push(context, YourRoute());
no setter

Functions

defaultLogWriterCallback(String value, {bool isError = false}) → void
default logger from JetX
removeLastHistory(String? url) → void
setUrlStrategy() → void

Typedefs

GetRouteAwarePageBuilder<T> = Widget Function([JetPageRoute<T>? route])
JetPageBuilder = Widget Function()
LogWriterCallback = void Function(String text, {bool isError})
VoidCallback from logs
OnHover = void Function(JetSnackBar snack, SnackHoverState snackHoverState)
OnTap = void Function(JetSnackBar snack)
SnackbarStatusCallback = void Function(SnackbarStatus? status)
ValueUpdater<T> = T Function()