jet_state_manager/src/simple/jet_state library
Classes
-
Bind<
T> -
BindElement<
T> - The BindElement is responsible for injecting dependencies into the widget tree so that they can be observed
-
Binder<
T> - Binding
-
Binding should be extended.
When using
JetMaterialApp, allJetPages and navigation methods (like Jet.to()) have abindingproperty that takes an instance of Bindings to manage the dependencies() (via Jet.put()) for the Route you are opening. - Binds
-
JetBuilder<
T extends JetxController>
Extensions
Typedefs
-
InitBuilder<
T> = T Function() -
JetControllerBuilder<
T extends JetLifeCycleMixin> = Widget Function(T controller)
Exceptions / Errors
-
BindError<
T>