jet_state_manager/src/simple/jet_view library

Classes

JetView<T>
JetView is a great way of quickly access your Controller without having to call Jet.find<AwesomeController>() yourself.
JetWidget<S extends JetLifeCycleMixin>
JetWidget is a great way of quickly access your individual Controller without having to call Jet.find<AwesomeController>() yourself. Jet save you controller on cache, so, you can to use Jet.create() safely JetWidget is perfect to multiples instance of a same controller. Each JetWidget will have your own controller, and will be call events as onInit and onClose when the controller get in/get out on memory.