route_manager library
Jet Navigator allows you to navigate routes, open snackbars, dialogs and bottomsheets easily, and without the need for context.
Classes
- BackButtonCallback
- CircularRevealClipper
- CircularRevealTransition
- CustomTransition
- Dependencies
- Engine
- FadeInTransition
-
GetBackGestureController<
T> -
GetBackGestureDetector<
T> -
GetBackGestureDetectorState<
T> - GetCupertinoApp
- GetDelegate
- GetInformationParser
- GetMiddleware
- The Page Middlewares. The Functions will be called in this order (( redirect -> onPageCalled -> onBindingsStart -> onPageBuildStart -> onPageBuilt -> onPageDispose ))
-
GetModalBottomSheetRoute<
T> - GetObserver
- GetRouterOutlet
-
IndexedRouteBuilder<
T> - JetInterface
- JetInterface allows any auxiliary package to be merged into the "Jet" class through extensions
- JetMaterialApp
-
JetPage<
T> -
JetPageRoute<
T> - JetSnackBar
- JetSnackBarState
- LeftToRightFadeTransition
- MiddlewareRunner
- Module
- ModuleState
- NoTransition
- PageRedirect
- PageSettings
- ParseRouteTree
- PathDecoded
- RightToLeftFadeTransition
- RouteDecoder
- RouteListenerState
- RouteReport
- RouteReportState
- RouterListener
- RouterListenerInherited
- RouterListenerState
-
RouterOutlet<
TDelegate extends RouterDelegate< T> , T extends Object> -
RouterOutletState<
TDelegate extends RouterDelegate< T> , T extends Object> - Routing
- SizeTransitions
- SlideDownTransition
- SlideLeftTransition
- SlideRightTransition
- SlideTopTransition
- SnackbarController
- SnackBarQueue
- Translations
- ZoomInTransition
Enums
- PopMode
- Enables the user to customize the intended pop behavior
- PreventDuplicateHandlingMode
- Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
- RowStyle
- SmartManagement
- Defines how JetX manages the lifecycle and disposal of controllers and dependencies.
- SnackbarStatus
-
Indicates Status of snackbar
SnackbarStatus.OPENSnack is fully open,SnackbarStatus.CLOSEDSnackbar has closed,SnackbarStatus.OPENINGStarts with the opening animation and ends with the full snackbar display,SnackbarStatus.CLOSINGStarts with the closing animation and ends with the full snackbar dispose - SnackHoverState
- Indicates if the mouse entered or exited
- SnackPosition
-
Indicates if snack is going to start at the
TOPor at theBOTTOM - SnackStyle
- Indicates if snack will be attached to the edge of the screen or not
- Transition
Mixins
-
JetPageRouteTransitionMixin<
T> -
PageRouteReportMixin<
T> -
RouteReportMixin<
T extends StatefulWidget> -
RouterListenerMixin<
T extends StatefulWidget>
Extensions
Constants
-
rtlLanguages
→ const List<
String>
Properties
- Jet → _JetImpl
-
final
-
It replaces the Flutter Navigator, but needs no context.
You can to use navigator.push(YourRoute()) rather
Navigator.push(context, YourRoute());
no setter
Functions
-
defaultLogWriterCallback(
String value, {bool isError = false}) → void - default logger from JetX
-
removeLastHistory(
String? url) → void -
setUrlStrategy(
) → void
Typedefs
-
GetRouteAwarePageBuilder<
T> = Widget Function([JetPageRoute< T> ? route]) - JetPageBuilder = Widget Function()
- LogWriterCallback = void Function(String text, {bool isError})
- VoidCallback from logs
- OnHover = void Function(JetSnackBar snack, SnackHoverState snackHoverState)
- OnTap = void Function(JetSnackBar snack)
- SnackbarStatusCallback = void Function(SnackbarStatus? status)
-
ValueUpdater<
T> = T Function()